spannertools.get_the_only_spanner_attached_to_any_improper_parent_of_component
==============================================================================

.. autofunction:: abjad.tools.spannertools.get_the_only_spanner_attached_to_any_improper_parent_of_component.get_the_only_spanner_attached_to_any_improper_parent_of_component
